@@ -1,5 +1,6 @@
-#  gnutrition - a nutrition and diet analysis program.
-#  Copyright( C) 2000 - 2002 Edgar Denny (edenny@skyweb.net)
+#  GNUtrition - a nutrition and diet analysis program.
+#  Copyright(C) 2000 - 2002 Edgar Denny (edenny@skyweb.net)
+#  Copyright (C) 2012 Free Software Foundation, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,16 +17,17 @@
 #
 
 import shelve
-import os
+from os import environ, path, access, F_OK, mkdir
 
-dir = os.environ['HOME'] + '/.gnutrition'
-fn = dir + '/config'
+home = environ['HOME']
+user = path.basename(home)
+udir = path.join(home, '.gnutrition')
+fn = path.join(udir, 'config')
+if not access(udir, F_OK):
+    mkdir(udir)
 
-if not os.access( dir, os.F_OK):
-    os.mkdir( dir)
-
-def get_value( key):
-    db = shelve.open( fn, 'c')
+def get_value(key):
+    db = shelve.open(fn, 'c')
     try:
         value = db[key]
     except KeyError:
@@ -33,7 +35,7 @@ def get_value( key):
     db.close()
     return value
 
-def set_key_value( key, value):
-    db = shelve.open( fn)
+def set_key_value(key, value):
+    db = shelve.open(fn)
     db[key] = value
     db.close()
